summaryrefslogtreecommitdiffstats
path: root/tests/ui/rfcs/rfc-2632-const-trait-impl/match-non-const-eq.rs
diff options
context:
space:
mode:
Diffstat (limited to 'tests/ui/rfcs/rfc-2632-const-trait-impl/match-non-const-eq.rs')
-rw-r--r--tests/ui/rfcs/rfc-2632-const-trait-impl/match-non-const-eq.rs5
1 files changed, 3 insertions, 2 deletions
diff --git a/tests/ui/rfcs/rfc-2632-const-trait-impl/match-non-const-eq.rs b/tests/ui/rfcs/rfc-2632-const-trait-impl/match-non-const-eq.rs
index 0d04101a3..d06d0d6dd 100644
--- a/tests/ui/rfcs/rfc-2632-const-trait-impl/match-non-const-eq.rs
+++ b/tests/ui/rfcs/rfc-2632-const-trait-impl/match-non-const-eq.rs
@@ -1,10 +1,11 @@
+// known-bug: #110395
// revisions: stock gated
#![cfg_attr(gated, feature(const_trait_impl))]
const fn foo(input: &'static str) {
match input {
- "a" => (), //[gated]~ ERROR can't compare `str` with `str` in const contexts
- //~^ ERROR cannot match on `str` in constant functions
+ "a" => (), //FIXME [gated]~ ERROR can't compare `str` with `str` in const contexts
+ //FIXME ~^ ERROR cannot match on `str` in constant functions
_ => (),
}
}